# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class IntegrationUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'default_responder_id': 'str',
        'project_id': 'str',
        'client_email': 'str',
        'private_key': 'str',
        'server_key': 'str',
        'sender_id': 'str',
        'can_user_create_more_conversations': 'bool',
        'authentication_message_secret': 'str',
        'page_access_token': 'str',
        'certificate': 'str',
        'password': 'str',
        'production': 'bool',
        'auto_update_badge': 'bool',
        'hide_unsubscribe_link': 'bool',
        'from_address': 'str',
        'brand_color': 'str',
        'fixed_intro_pane': 'bool',
        'conversation_color': 'str',
        'action_color': 'str',
        'display_style': 'str',
        'button_icon_url': 'str',
        'button_width': 'str',
        'button_height': 'str',
        'integration_order': 'list[str]',
        'business_name': 'str',
        'business_icon_url': 'str',
        'background_image_url': 'str',
        'origin_whitelist': 'list[str]',
        'prechat_capture': 'PrechatCapture',
        'hsm_fallback_language': 'str',
        'account_id': 'str',
        'account_management_access_token': 'str'
    }

    attribute_map = {
        'display_name': 'displayName',
        'default_responder_id': 'defaultResponderId',
        'project_id': 'projectId',
        'client_email': 'clientEmail',
        'private_key': 'privateKey',
        'server_key': 'serverKey',
        'sender_id': 'senderId',
        'can_user_create_more_conversations': 'canUserCreateMoreConversations',
        'authentication_message_secret': 'authenticationMessageSecret',
        'page_access_token': 'pageAccessToken',
        'certificate': 'certificate',
        'password': 'password',
        'production': 'production',
        'auto_update_badge': 'autoUpdateBadge',
        'hide_unsubscribe_link': 'hideUnsubscribeLink',
        'from_address': 'fromAddress',
        'brand_color': 'brandColor',
        'fixed_intro_pane': 'fixedIntroPane',
        'conversation_color': 'conversationColor',
        'action_color': 'actionColor',
        'display_style': 'displayStyle',
        'button_icon_url': 'buttonIconUrl',
        'button_width': 'buttonWidth',
        'button_height': 'buttonHeight',
        'integration_order': 'integrationOrder',
        'business_name': 'businessName',
        'business_icon_url': 'businessIconUrl',
        'background_image_url': 'backgroundImageUrl',
        'origin_whitelist': 'originWhitelist',
        'prechat_capture': 'prechatCapture',
        'hsm_fallback_language': 'hsmFallbackLanguage',
        'account_id': 'accountId',
        'account_management_access_token': 'accountManagementAccessToken'
    }

    nulls = set()

    def __init__(self, display_name=Undefined(), default_responder_id=Undefined(), project_id=Undefined(), client_email=Undefined(), private_key=Undefined(), server_key=Undefined(), sender_id=Undefined(), can_user_create_more_conversations=None, authentication_message_secret=None, page_access_token=None, certificate=Undefined(), password=None, production=None, auto_update_badge=None, hide_unsubscribe_link=None, from_address=Undefined(), brand_color='65758e', fixed_intro_pane=False, conversation_color='0099ff', action_color='0099ff', display_style='button', button_icon_url=Undefined(), button_width='58', button_height='58', integration_order=Undefined(), business_name=None, business_icon_url=None, background_image_url=None, origin_whitelist=Undefined(), prechat_capture=None, hsm_fallback_language='en_US', account_id=Undefined(), account_management_access_token=Undefined(), local_vars_configuration=None):  # noqa: E501
        """IntegrationUpdate - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._default_responder_id = None
        self._project_id = None
        self._client_email = None
        self._private_key = None
        self._server_key = None
        self._sender_id = None
        self._can_user_create_more_conversations = None
        self._authentication_message_secret = None
        self._page_access_token = None
        self._certificate = None
        self._password = None
        self._production = None
        self._auto_update_badge = None
        self._hide_unsubscribe_link = None
        self._from_address = None
        self._brand_color = None
        self._fixed_intro_pane = None
        self._conversation_color = None
        self._action_color = None
        self._display_style = None
        self._button_icon_url = None
        self._button_width = None
        self._button_height = None
        self._integration_order = None
        self._business_name = None
        self._business_icon_url = None
        self._background_image_url = None
        self._origin_whitelist = None
        self._prechat_capture = None
        self._hsm_fallback_language = None
        self._account_id = None
        self._account_management_access_token = None
        self.discriminator = None

        self.display_name = display_name
        self.default_responder_id = default_responder_id
        self.project_id = project_id
        self.client_email = client_email
        self.private_key = private_key
        self.server_key = server_key
        self.sender_id = sender_id
        if can_user_create_more_conversations is not None:
            self.can_user_create_more_conversations = can_user_create_more_conversations
        if authentication_message_secret is not None:
            self.authentication_message_secret = authentication_message_secret
        if page_access_token is not None:
            self.page_access_token = page_access_token
        self.certificate = certificate
        if password is not None:
            self.password = password
        if production is not None:
            self.production = production
        if auto_update_badge is not None:
            self.auto_update_badge = auto_update_badge
        if hide_unsubscribe_link is not None:
            self.hide_unsubscribe_link = hide_unsubscribe_link
        self.from_address = from_address
        if brand_color is not None:
            self.brand_color = brand_color
        if fixed_intro_pane is not None:
            self.fixed_intro_pane = fixed_intro_pane
        if conversation_color is not None:
            self.conversation_color = conversation_color
        if action_color is not None:
            self.action_color = action_color
        if display_style is not None:
            self.display_style = display_style
        self.button_icon_url = button_icon_url
        if button_width is not None:
            self.button_width = button_width
        if button_height is not None:
            self.button_height = button_height
        self.integration_order = integration_order
        if business_name is not None:
            self.business_name = business_name
        if business_icon_url is not None:
            self.business_icon_url = business_icon_url
        if background_image_url is not None:
            self.background_image_url = background_image_url
        self.origin_whitelist = origin_whitelist
        if prechat_capture is not None:
            self.prechat_capture = prechat_capture
        self.hsm_fallback_language = hsm_fallback_language
        self.account_id = account_id
        self.account_management_access_token = account_management_access_token

    @property
    def display_name(self):
        """Gets the display_name of this IntegrationUpdate.  # noqa: E501

        A human-friendly name used to identify the integration. `displayName` can be unset by changing it to `null`.  # noqa: E501

        :return: The display_name of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this IntegrationUpdate.

        A human-friendly name used to identify the integration. `displayName` can be unset by changing it to `null`.  # noqa: E501

        :param display_name: The display_name of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(display_name) is Undefined:
            display_name = None
            self.nulls.discard("display_name")
        elif display_name is None:
            self.nulls.add("display_name")
        else:
            self.nulls.discard("display_name")
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 100):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) < 1):
            raise ValueError("Invalid value for `display_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._display_name = display_name

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this IntegrationUpdate.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this IntegrationUpdate.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def project_id(self):
        """Gets the project_id of this IntegrationUpdate.  # noqa: E501

        Your project ID from your generated private key file.  # noqa: E501

        :return: The project_id of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this IntegrationUpdate.

        Your project ID from your generated private key file.  # noqa: E501

        :param project_id: The project_id of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(project_id) is Undefined:
            project_id = None
            self.nulls.discard("project_id")
        elif project_id is None:
            self.nulls.add("project_id")
        else:
            self.nulls.discard("project_id")
        if (self.local_vars_configuration.client_side_validation and
                project_id is not None and len(project_id) < 1):
            raise ValueError("Invalid value for `project_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._project_id = project_id

    @property
    def client_email(self):
        """Gets the client_email of this IntegrationUpdate.  # noqa: E501

        Your client email from your generated private key file.  # noqa: E501

        :return: The client_email of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._client_email

    @client_email.setter
    def client_email(self, client_email):
        """Sets the client_email of this IntegrationUpdate.

        Your client email from your generated private key file.  # noqa: E501

        :param client_email: The client_email of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(client_email) is Undefined:
            client_email = None
            self.nulls.discard("client_email")
        elif client_email is None:
            self.nulls.add("client_email")
        else:
            self.nulls.discard("client_email")
        if (self.local_vars_configuration.client_side_validation and
                client_email is not None and len(client_email) < 1):
            raise ValueError("Invalid value for `client_email`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_email = client_email

    @property
    def private_key(self):
        """Gets the private_key of this IntegrationUpdate.  # noqa: E501

        Your private key from your generated private key file.  # noqa: E501

        :return: The private_key of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this IntegrationUpdate.

        Your private key from your generated private key file.  # noqa: E501

        :param private_key: The private_key of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(private_key) is Undefined:
            private_key = None
            self.nulls.discard("private_key")
        elif private_key is None:
            self.nulls.add("private_key")
        else:
            self.nulls.discard("private_key")
        if (self.local_vars_configuration.client_side_validation and
                private_key is not None and len(private_key) < 1):
            raise ValueError("Invalid value for `private_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._private_key = private_key

    @property
    def server_key(self):
        """Gets the server_key of this IntegrationUpdate.  # noqa: E501

        Your server key from the fcm console.  # noqa: E501

        :return: The server_key of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._server_key

    @server_key.setter
    def server_key(self, server_key):
        """Sets the server_key of this IntegrationUpdate.

        Your server key from the fcm console.  # noqa: E501

        :param server_key: The server_key of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(server_key) is Undefined:
            server_key = None
            self.nulls.discard("server_key")
        elif server_key is None:
            self.nulls.add("server_key")
        else:
            self.nulls.discard("server_key")
        if (self.local_vars_configuration.client_side_validation and
                server_key is not None and len(server_key) < 1):
            raise ValueError("Invalid value for `server_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._server_key = server_key

    @property
    def sender_id(self):
        """Gets the sender_id of this IntegrationUpdate.  # noqa: E501

        Your sender id from the fcm console.  # noqa: E501

        :return: The sender_id of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._sender_id

    @sender_id.setter
    def sender_id(self, sender_id):
        """Sets the sender_id of this IntegrationUpdate.

        Your sender id from the fcm console.  # noqa: E501

        :param sender_id: The sender_id of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(sender_id) is Undefined:
            sender_id = None
            self.nulls.discard("sender_id")
        elif sender_id is None:
            self.nulls.add("sender_id")
        else:
            self.nulls.discard("sender_id")
        if (self.local_vars_configuration.client_side_validation and
                sender_id is not None and len(sender_id) < 1):
            raise ValueError("Invalid value for `sender_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._sender_id = sender_id

    @property
    def can_user_create_more_conversations(self):
        """Gets the can_user_create_more_conversations of this IntegrationUpdate.  # noqa: E501

        Allows users to create more than one conversation on the web messenger integration.  # noqa: E501

        :return: The can_user_create_more_conversations of this IntegrationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._can_user_create_more_conversations

    @can_user_create_more_conversations.setter
    def can_user_create_more_conversations(self, can_user_create_more_conversations):
        """Sets the can_user_create_more_conversations of this IntegrationUpdate.

        Allows users to create more than one conversation on the web messenger integration.  # noqa: E501

        :param can_user_create_more_conversations: The can_user_create_more_conversations of this IntegrationUpdate.  # noqa: E501
        :type: bool
        """

        self._can_user_create_more_conversations = can_user_create_more_conversations

    @property
    def authentication_message_secret(self):
        """Gets the authentication_message_secret of this IntegrationUpdate.  # noqa: E501

        A secret used to create the state value when sending Apple authentication 2.0 messages  # noqa: E501

        :return: The authentication_message_secret of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._authentication_message_secret

    @authentication_message_secret.setter
    def authentication_message_secret(self, authentication_message_secret):
        """Sets the authentication_message_secret of this IntegrationUpdate.

        A secret used to create the state value when sending Apple authentication 2.0 messages  # noqa: E501

        :param authentication_message_secret: The authentication_message_secret of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                authentication_message_secret is not None and len(authentication_message_secret) < 88):
            raise ValueError("Invalid value for `authentication_message_secret`, length must be greater than or equal to `88`")  # noqa: E501

        self._authentication_message_secret = authentication_message_secret

    @property
    def page_access_token(self):
        """Gets the page_access_token of this IntegrationUpdate.  # noqa: E501

        A Facebook Page Access Token.  # noqa: E501

        :return: The page_access_token of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._page_access_token

    @page_access_token.setter
    def page_access_token(self, page_access_token):
        """Sets the page_access_token of this IntegrationUpdate.

        A Facebook Page Access Token.  # noqa: E501

        :param page_access_token: The page_access_token of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._page_access_token = page_access_token

    @property
    def certificate(self):
        """Gets the certificate of this IntegrationUpdate.  # noqa: E501

        The binary of your APN certificate base64 encoded.  # noqa: E501

        :return: The certificate of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this IntegrationUpdate.

        The binary of your APN certificate base64 encoded.  # noqa: E501

        :param certificate: The certificate of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(certificate) is Undefined:
            certificate = None
            self.nulls.discard("certificate")
        elif certificate is None:
            self.nulls.add("certificate")
        else:
            self.nulls.discard("certificate")
        if (self.local_vars_configuration.client_side_validation and
                certificate is not None and len(certificate) < 1):
            raise ValueError("Invalid value for `certificate`, length must be greater than or equal to `1`")  # noqa: E501

        self._certificate = certificate

    @property
    def password(self):
        """Gets the password of this IntegrationUpdate.  # noqa: E501

        The password for your APN certificate.  # noqa: E501

        :return: The password of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this IntegrationUpdate.

        The password for your APN certificate.  # noqa: E501

        :param password: The password of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def production(self):
        """Gets the production of this IntegrationUpdate.  # noqa: E501

        The APN environment to connect to (Production, if true, or Sandbox). Defaults to value inferred from certificate if not specified.  # noqa: E501

        :return: The production of this IntegrationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """Sets the production of this IntegrationUpdate.

        The APN environment to connect to (Production, if true, or Sandbox). Defaults to value inferred from certificate if not specified.  # noqa: E501

        :param production: The production of this IntegrationUpdate.  # noqa: E501
        :type: bool
        """

        self._production = production

    @property
    def auto_update_badge(self):
        """Gets the auto_update_badge of this IntegrationUpdate.  # noqa: E501

        Use the unread count of the conversation as the application badge.  # noqa: E501

        :return: The auto_update_badge of this IntegrationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._auto_update_badge

    @auto_update_badge.setter
    def auto_update_badge(self, auto_update_badge):
        """Sets the auto_update_badge of this IntegrationUpdate.

        Use the unread count of the conversation as the application badge.  # noqa: E501

        :param auto_update_badge: The auto_update_badge of this IntegrationUpdate.  # noqa: E501
        :type: bool
        """

        self._auto_update_badge = auto_update_badge

    @property
    def hide_unsubscribe_link(self):
        """Gets the hide_unsubscribe_link of this IntegrationUpdate.  # noqa: E501

        A boolean value indicating whether the unsubscribe link should be omitted from outgoing emails. When enabled, it is expected that the business is providing the user a way to unsubscribe by some other means. By default, the unsubscribe link will be included in all outgoing emails.  # noqa: E501

        :return: The hide_unsubscribe_link of this IntegrationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._hide_unsubscribe_link

    @hide_unsubscribe_link.setter
    def hide_unsubscribe_link(self, hide_unsubscribe_link):
        """Sets the hide_unsubscribe_link of this IntegrationUpdate.

        A boolean value indicating whether the unsubscribe link should be omitted from outgoing emails. When enabled, it is expected that the business is providing the user a way to unsubscribe by some other means. By default, the unsubscribe link will be included in all outgoing emails.  # noqa: E501

        :param hide_unsubscribe_link: The hide_unsubscribe_link of this IntegrationUpdate.  # noqa: E501
        :type: bool
        """

        self._hide_unsubscribe_link = hide_unsubscribe_link

    @property
    def from_address(self):
        """Gets the from_address of this IntegrationUpdate.  # noqa: E501

        Email address to use as the From and Reply-To address if it must be different from incomingAddress. Only use this option if the address that you supply is configured to forward emails to the incomingAddress, otherwise user replies will be lost. You must also make sure that the domain is properly configured as a mail provider so as to not be flagged as spam by the user’s email client. May be unset with null.  # noqa: E501

        :return: The from_address of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this IntegrationUpdate.

        Email address to use as the From and Reply-To address if it must be different from incomingAddress. Only use this option if the address that you supply is configured to forward emails to the incomingAddress, otherwise user replies will be lost. You must also make sure that the domain is properly configured as a mail provider so as to not be flagged as spam by the user’s email client. May be unset with null.  # noqa: E501

        :param from_address: The from_address of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(from_address) is Undefined:
            from_address = None
            self.nulls.discard("from_address")
        elif from_address is None:
            self.nulls.add("from_address")
        else:
            self.nulls.discard("from_address")
        if (self.local_vars_configuration.client_side_validation and
                from_address is not None and len(from_address) < 1):
            raise ValueError("Invalid value for `from_address`, length must be greater than or equal to `1`")  # noqa: E501

        self._from_address = from_address

    @property
    def brand_color(self):
        """Gets the brand_color of this IntegrationUpdate.  # noqa: E501

        This color will be used in the messenger header and the button or tab in idle state. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :return: The brand_color of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._brand_color

    @brand_color.setter
    def brand_color(self, brand_color):
        """Sets the brand_color of this IntegrationUpdate.

        This color will be used in the messenger header and the button or tab in idle state. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :param brand_color: The brand_color of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._brand_color = brand_color

    @property
    def fixed_intro_pane(self):
        """Gets the fixed_intro_pane of this IntegrationUpdate.  # noqa: E501

        When true, the introduction pane will be pinned at the top of the conversation instead of scrolling with it.  # noqa: E501

        :return: The fixed_intro_pane of this IntegrationUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_intro_pane

    @fixed_intro_pane.setter
    def fixed_intro_pane(self, fixed_intro_pane):
        """Sets the fixed_intro_pane of this IntegrationUpdate.

        When true, the introduction pane will be pinned at the top of the conversation instead of scrolling with it.  # noqa: E501

        :param fixed_intro_pane: The fixed_intro_pane of this IntegrationUpdate.  # noqa: E501
        :type: bool
        """

        self._fixed_intro_pane = fixed_intro_pane

    @property
    def conversation_color(self):
        """Gets the conversation_color of this IntegrationUpdate.  # noqa: E501

        This color will be used for customer messages, quick replies and actions in the footer. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :return: The conversation_color of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._conversation_color

    @conversation_color.setter
    def conversation_color(self, conversation_color):
        """Sets the conversation_color of this IntegrationUpdate.

        This color will be used for customer messages, quick replies and actions in the footer. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :param conversation_color: The conversation_color of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._conversation_color = conversation_color

    @property
    def action_color(self):
        """Gets the action_color of this IntegrationUpdate.  # noqa: E501

        This color will be used for call-to-actions inside your messages. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :return: The action_color of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._action_color

    @action_color.setter
    def action_color(self, action_color):
        """Sets the action_color of this IntegrationUpdate.

        This color will be used for call-to-actions inside your messages. Must be a 3 or 6-character hexadecimal color.  # noqa: E501

        :param action_color: The action_color of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._action_color = action_color

    @property
    def display_style(self):
        """Gets the display_style of this IntegrationUpdate.  # noqa: E501

        Choose how the messenger will appear on your website. Must be either button or tab.  # noqa: E501

        :return: The display_style of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._display_style

    @display_style.setter
    def display_style(self, display_style):
        """Sets the display_style of this IntegrationUpdate.

        Choose how the messenger will appear on your website. Must be either button or tab.  # noqa: E501

        :param display_style: The display_style of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._display_style = display_style

    @property
    def button_icon_url(self):
        """Gets the button_icon_url of this IntegrationUpdate.  # noqa: E501

        With the button style Web Messenger, you have the option of selecting your own button icon. The image must be at least 200 x 200 pixels and must be in either JPG, PNG, or GIF format.  # noqa: E501

        :return: The button_icon_url of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._button_icon_url

    @button_icon_url.setter
    def button_icon_url(self, button_icon_url):
        """Sets the button_icon_url of this IntegrationUpdate.

        With the button style Web Messenger, you have the option of selecting your own button icon. The image must be at least 200 x 200 pixels and must be in either JPG, PNG, or GIF format.  # noqa: E501

        :param button_icon_url: The button_icon_url of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(button_icon_url) is Undefined:
            button_icon_url = None
            self.nulls.discard("button_icon_url")
        elif button_icon_url is None:
            self.nulls.add("button_icon_url")
        else:
            self.nulls.discard("button_icon_url")

        self._button_icon_url = button_icon_url

    @property
    def button_width(self):
        """Gets the button_width of this IntegrationUpdate.  # noqa: E501

        With the button style Web Messenger, you have the option of specifying the button width.  # noqa: E501

        :return: The button_width of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._button_width

    @button_width.setter
    def button_width(self, button_width):
        """Sets the button_width of this IntegrationUpdate.

        With the button style Web Messenger, you have the option of specifying the button width.  # noqa: E501

        :param button_width: The button_width of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._button_width = button_width

    @property
    def button_height(self):
        """Gets the button_height of this IntegrationUpdate.  # noqa: E501

        With the button style Web Messenger, you have the option of specifying the button height.  # noqa: E501

        :return: The button_height of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._button_height

    @button_height.setter
    def button_height(self, button_height):
        """Sets the button_height of this IntegrationUpdate.

        With the button style Web Messenger, you have the option of specifying the button height.  # noqa: E501

        :param button_height: The button_height of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._button_height = button_height

    @property
    def integration_order(self):
        """Gets the integration_order of this IntegrationUpdate.  # noqa: E501

        Array of integration IDs, order will be reflected in the Web Messenger. When set, only integrations from this list will be displayed in the Web Messenger. If unset, all integrations will be displayed.  # noqa: E501

        :return: The integration_order of this IntegrationUpdate.  # noqa: E501
        :rtype: list[str]
        """
        return self._integration_order

    @integration_order.setter
    def integration_order(self, integration_order):
        """Sets the integration_order of this IntegrationUpdate.

        Array of integration IDs, order will be reflected in the Web Messenger. When set, only integrations from this list will be displayed in the Web Messenger. If unset, all integrations will be displayed.  # noqa: E501

        :param integration_order: The integration_order of this IntegrationUpdate.  # noqa: E501
        :type: list[str]
        """
        if type(integration_order) is Undefined:
            integration_order = None
            self.nulls.discard("integration_order")
        elif integration_order is None:
            self.nulls.add("integration_order")
        else:
            self.nulls.discard("integration_order")

        self._integration_order = integration_order

    @property
    def business_name(self):
        """Gets the business_name of this IntegrationUpdate.  # noqa: E501

        A custom business name for the Web Messenger.  # noqa: E501

        :return: The business_name of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """Sets the business_name of this IntegrationUpdate.

        A custom business name for the Web Messenger.  # noqa: E501

        :param business_name: The business_name of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._business_name = business_name

    @property
    def business_icon_url(self):
        """Gets the business_icon_url of this IntegrationUpdate.  # noqa: E501

        A custom business icon url for the Web Messenger. The image must be at least 200 x 200 pixels and must be in either JPG, PNG, or GIF format.  # noqa: E501

        :return: The business_icon_url of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._business_icon_url

    @business_icon_url.setter
    def business_icon_url(self, business_icon_url):
        """Sets the business_icon_url of this IntegrationUpdate.

        A custom business icon url for the Web Messenger. The image must be at least 200 x 200 pixels and must be in either JPG, PNG, or GIF format.  # noqa: E501

        :param business_icon_url: The business_icon_url of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._business_icon_url = business_icon_url

    @property
    def background_image_url(self):
        """Gets the background_image_url of this IntegrationUpdate.  # noqa: E501

        A background image url for the conversation. Image will be tiled to fit the window.  # noqa: E501

        :return: The background_image_url of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._background_image_url

    @background_image_url.setter
    def background_image_url(self, background_image_url):
        """Sets the background_image_url of this IntegrationUpdate.

        A background image url for the conversation. Image will be tiled to fit the window.  # noqa: E501

        :param background_image_url: The background_image_url of this IntegrationUpdate.  # noqa: E501
        :type: str
        """

        self._background_image_url = background_image_url

    @property
    def origin_whitelist(self):
        """Gets the origin_whitelist of this IntegrationUpdate.  # noqa: E501

        A list of origins to whitelist. When set, only the origins from this list will be able to initialize the Web Messenger. If unset, all origins are whitelisted. The elements in the list should follow the serialized-origin format from RFC 6454: scheme \"://\" host [ \":\" port ], where scheme is http or https.   # noqa: E501

        :return: The origin_whitelist of this IntegrationUpdate.  # noqa: E501
        :rtype: list[str]
        """
        return self._origin_whitelist

    @origin_whitelist.setter
    def origin_whitelist(self, origin_whitelist):
        """Sets the origin_whitelist of this IntegrationUpdate.

        A list of origins to whitelist. When set, only the origins from this list will be able to initialize the Web Messenger. If unset, all origins are whitelisted. The elements in the list should follow the serialized-origin format from RFC 6454: scheme \"://\" host [ \":\" port ], where scheme is http or https.   # noqa: E501

        :param origin_whitelist: The origin_whitelist of this IntegrationUpdate.  # noqa: E501
        :type: list[str]
        """
        if type(origin_whitelist) is Undefined:
            origin_whitelist = None
            self.nulls.discard("origin_whitelist")
        elif origin_whitelist is None:
            self.nulls.add("origin_whitelist")
        else:
            self.nulls.discard("origin_whitelist")

        self._origin_whitelist = origin_whitelist

    @property
    def prechat_capture(self):
        """Gets the prechat_capture of this IntegrationUpdate.  # noqa: E501

        Object whose properties can be set to specify the add-on’s options. See the [guide](https://docs.smooch.io/guide/web-messenger/#prechat-capture) to learn more about Prechat Capture.  # noqa: E501

        :return: The prechat_capture of this IntegrationUpdate.  # noqa: E501
        :rtype: PrechatCapture
        """
        return self._prechat_capture

    @prechat_capture.setter
    def prechat_capture(self, prechat_capture):
        """Sets the prechat_capture of this IntegrationUpdate.

        Object whose properties can be set to specify the add-on’s options. See the [guide](https://docs.smooch.io/guide/web-messenger/#prechat-capture) to learn more about Prechat Capture.  # noqa: E501

        :param prechat_capture: The prechat_capture of this IntegrationUpdate.  # noqa: E501
        :type: PrechatCapture
        """

        self._prechat_capture = prechat_capture

    @property
    def hsm_fallback_language(self):
        """Gets the hsm_fallback_language of this IntegrationUpdate.  # noqa: E501

        Specify a fallback language to use when sending WhatsApp message template using the short hand syntax. Defaults to en_US. See WhatsApp documentation for more info.  # noqa: E501

        :return: The hsm_fallback_language of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._hsm_fallback_language

    @hsm_fallback_language.setter
    def hsm_fallback_language(self, hsm_fallback_language):
        """Sets the hsm_fallback_language of this IntegrationUpdate.

        Specify a fallback language to use when sending WhatsApp message template using the short hand syntax. Defaults to en_US. See WhatsApp documentation for more info.  # noqa: E501

        :param hsm_fallback_language: The hsm_fallback_language of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(hsm_fallback_language) is Undefined:
            hsm_fallback_language = None
            self.nulls.discard("hsm_fallback_language")
        elif hsm_fallback_language is None:
            self.nulls.add("hsm_fallback_language")
        else:
            self.nulls.discard("hsm_fallback_language")

        self._hsm_fallback_language = hsm_fallback_language

    @property
    def account_id(self):
        """Gets the account_id of this IntegrationUpdate.  # noqa: E501

        The business ID associated with the WhatsApp account. In combination with accountManagementAccessToken, it’s used for Message Template Reconstruction.  # noqa: E501

        :return: The account_id of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this IntegrationUpdate.

        The business ID associated with the WhatsApp account. In combination with accountManagementAccessToken, it’s used for Message Template Reconstruction.  # noqa: E501

        :param account_id: The account_id of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(account_id) is Undefined:
            account_id = None
            self.nulls.discard("account_id")
        elif account_id is None:
            self.nulls.add("account_id")
        else:
            self.nulls.discard("account_id")

        self._account_id = account_id

    @property
    def account_management_access_token(self):
        """Gets the account_management_access_token of this IntegrationUpdate.  # noqa: E501

        An access token associated with the accountId used to query the WhatsApp Account Management API. In combination with accountId, it’s used for Message Template Reconstruction.  # noqa: E501

        :return: The account_management_access_token of this IntegrationUpdate.  # noqa: E501
        :rtype: str
        """
        return self._account_management_access_token

    @account_management_access_token.setter
    def account_management_access_token(self, account_management_access_token):
        """Sets the account_management_access_token of this IntegrationUpdate.

        An access token associated with the accountId used to query the WhatsApp Account Management API. In combination with accountId, it’s used for Message Template Reconstruction.  # noqa: E501

        :param account_management_access_token: The account_management_access_token of this IntegrationUpdate.  # noqa: E501
        :type: str
        """
        if type(account_management_access_token) is Undefined:
            account_management_access_token = None
            self.nulls.discard("account_management_access_token")
        elif account_management_access_token is None:
            self.nulls.add("account_management_access_token")
        else:
            self.nulls.discard("account_management_access_token")

        self._account_management_access_token = account_management_access_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegrationUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class SwitchboardAcceptControlFailureAllOfPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error': 'object',
        'conversation': 'ConversationTruncated',
        'metadata': 'object'
    }

    attribute_map = {
        'error': 'error',
        'conversation': 'conversation',
        'metadata': 'metadata'
    }

    nulls = set()

    def __init__(self, error=None, conversation=None, metadata=Undefined(), local_vars_configuration=None):  # noqa: E501
        """SwitchboardAcceptControlFailureAllOfPayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error = None
        self._conversation = None
        self._metadata = None
        self.discriminator = None

        if error is not None:
            self.error = error
        if conversation is not None:
            self.conversation = conversation
        self.metadata = metadata

    @property
    def error(self):
        """Gets the error of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501

        Object containing details of what went wrong.  # noqa: E501

        :return: The error of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :rtype: object
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this SwitchboardAcceptControlFailureAllOfPayload.

        Object containing details of what went wrong.  # noqa: E501

        :param error: The error of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :type: object
        """

        self._error = error

    @property
    def conversation(self):
        """Gets the conversation of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501

        The conversation from which the switchboard event was fired.  # noqa: E501

        :return: The conversation of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :rtype: ConversationTruncated
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """Sets the conversation of this SwitchboardAcceptControlFailureAllOfPayload.

        The conversation from which the switchboard event was fired.  # noqa: E501

        :param conversation: The conversation of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :type: ConversationTruncated
        """

        self._conversation = conversation

    @property
    def metadata(self):
        """Gets the metadata of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501

        Flat object containing custom properties. Strings, numbers and booleans  are the only supported format that can be passed to metadata. The metadata is limited to 4KB in size.   # noqa: E501

        :return: The metadata of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this SwitchboardAcceptControlFailureAllOfPayload.

        Flat object containing custom properties. Strings, numbers and booleans  are the only supported format that can be passed to metadata. The metadata is limited to 4KB in size.   # noqa: E501

        :param metadata: The metadata of this SwitchboardAcceptControlFailureAllOfPayload.  # noqa: E501
        :type: object
        """
        if type(metadata) is Undefined:
            metadata = None
            self.nulls.discard("metadata")
        elif metadata is None:
            self.nulls.add("metadata")
        else:
            self.nulls.discard("metadata")

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwitchboardAcceptControlFailureAllOfPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SwitchboardAcceptControlFailureAllOfPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined

try:
    Integration = __import__("sunshine_conversations_client.model."+re.sub(r'(?<!^)(?=[A-Z])', '_', "Integration").lower(), fromlist=("Integration")).Integration
except ImportError:
    pass

class Apple(Integration):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'business_id': 'str',
        'api_secret': 'str',
        'msp_id': 'str',
        'authentication_message_secret': 'str',
        'default_responder_id': 'str',
        'default_responder': 'DefaultResponderDefaultResponder'
    }

    attribute_map = {
        'type': 'type',
        'business_id': 'businessId',
        'api_secret': 'apiSecret',
        'msp_id': 'mspId',
        'authentication_message_secret': 'authenticationMessageSecret',
        'default_responder_id': 'defaultResponderId',
        'default_responder': 'defaultResponder'
    }

    nulls = set()

    def __init__(self, type='apple', business_id=None, api_secret=None, msp_id=None, authentication_message_secret=None, default_responder_id=Undefined(), default_responder=None, local_vars_configuration=None, **kwargs):  # noqa: E501
        """Apple - a model defined in OpenAPI"""  # noqa: E501
        super().__init__(**kwargs)

        if (super().openapi_types is not None):
            all_types = super().openapi_types.copy()
            all_types.update(self.openapi_types)
            self.openapi_types = all_types

        if (super().attribute_map is not None):
            all_attributes = super().attribute_map.copy()
            all_attributes.update(self.attribute_map)
            self.attribute_map = all_attributes
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._business_id = None
        self._api_secret = None
        self._msp_id = None
        self._authentication_message_secret = None
        self._default_responder_id = None
        self._default_responder = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.business_id = business_id
        if api_secret is not None:
            self.api_secret = api_secret
        self.msp_id = msp_id
        if authentication_message_secret is not None:
            self.authentication_message_secret = authentication_message_secret
        self.default_responder_id = default_responder_id
        if default_responder is not None:
            self.default_responder = default_responder

    @property
    def type(self):
        """Gets the type of this Apple.  # noqa: E501

        To configure an Apple Messages for Business integration, acquire the required information and call the Create Integration endpoint.   # noqa: E501

        :return: The type of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Apple.

        To configure an Apple Messages for Business integration, acquire the required information and call the Create Integration endpoint.   # noqa: E501

        :param type: The type of this Apple.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def business_id(self):
        """Gets the business_id of this Apple.  # noqa: E501

        Apple Messages for Business ID.  # noqa: E501

        :return: The business_id of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._business_id

    @business_id.setter
    def business_id(self, business_id):
        """Sets the business_id of this Apple.

        Apple Messages for Business ID.  # noqa: E501

        :param business_id: The business_id of this Apple.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and business_id is None:  # noqa: E501
            raise ValueError("Invalid value for `business_id`, must not be `None`")  # noqa: E501

        self._business_id = business_id

    @property
    def api_secret(self):
        """Gets the api_secret of this Apple.  # noqa: E501

        Your Apple API secret which is tied to your Messaging Service Provider.  # noqa: E501

        :return: The api_secret of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._api_secret

    @api_secret.setter
    def api_secret(self, api_secret):
        """Sets the api_secret of this Apple.

        Your Apple API secret which is tied to your Messaging Service Provider.  # noqa: E501

        :param api_secret: The api_secret of this Apple.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and api_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `api_secret`, must not be `None`")  # noqa: E501

        self._api_secret = api_secret

    @property
    def msp_id(self):
        """Gets the msp_id of this Apple.  # noqa: E501

        Your Messaging Service Provider ID.  # noqa: E501

        :return: The msp_id of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._msp_id

    @msp_id.setter
    def msp_id(self, msp_id):
        """Sets the msp_id of this Apple.

        Your Messaging Service Provider ID.  # noqa: E501

        :param msp_id: The msp_id of this Apple.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and msp_id is None:  # noqa: E501
            raise ValueError("Invalid value for `msp_id`, must not be `None`")  # noqa: E501

        self._msp_id = msp_id

    @property
    def authentication_message_secret(self):
        """Gets the authentication_message_secret of this Apple.  # noqa: E501

        A secret used to create the state value when sending Apple authentication 2.0 messages  # noqa: E501

        :return: The authentication_message_secret of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._authentication_message_secret

    @authentication_message_secret.setter
    def authentication_message_secret(self, authentication_message_secret):
        """Sets the authentication_message_secret of this Apple.

        A secret used to create the state value when sending Apple authentication 2.0 messages  # noqa: E501

        :param authentication_message_secret: The authentication_message_secret of this Apple.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                authentication_message_secret is not None and len(authentication_message_secret) < 88):
            raise ValueError("Invalid value for `authentication_message_secret`, length must be greater than or equal to `88`")  # noqa: E501

        self._authentication_message_secret = authentication_message_secret

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this Apple.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this Apple.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this Apple.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this Apple.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def default_responder(self):
        """Gets the default_responder of this Apple.  # noqa: E501


        :return: The default_responder of this Apple.  # noqa: E501
        :rtype: DefaultResponderDefaultResponder
        """
        return self._default_responder

    @default_responder.setter
    def default_responder(self, default_responder):
        """Sets the default_responder of this Apple.


        :param default_responder: The default_responder of this Apple.  # noqa: E501
        :type: DefaultResponderDefaultResponder
        """

        self._default_responder = default_responder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Apple):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Apple):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class WhatsAppUpdateAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hsm_fallback_language': 'str',
        'account_id': 'str',
        'account_management_access_token': 'str'
    }

    attribute_map = {
        'hsm_fallback_language': 'hsmFallbackLanguage',
        'account_id': 'accountId',
        'account_management_access_token': 'accountManagementAccessToken'
    }

    nulls = set()

    def __init__(self, hsm_fallback_language='en_US', account_id=Undefined(), account_management_access_token=Undefined(), local_vars_configuration=None):  # noqa: E501
        """WhatsAppUpdateAllOf - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._hsm_fallback_language = None
        self._account_id = None
        self._account_management_access_token = None
        self.discriminator = None

        self.hsm_fallback_language = hsm_fallback_language
        self.account_id = account_id
        self.account_management_access_token = account_management_access_token

    @property
    def hsm_fallback_language(self):
        """Gets the hsm_fallback_language of this WhatsAppUpdateAllOf.  # noqa: E501

        Specify a fallback language to use when sending WhatsApp message template using the short hand syntax. Defaults to en_US. See WhatsApp documentation for more info.  # noqa: E501

        :return: The hsm_fallback_language of this WhatsAppUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._hsm_fallback_language

    @hsm_fallback_language.setter
    def hsm_fallback_language(self, hsm_fallback_language):
        """Sets the hsm_fallback_language of this WhatsAppUpdateAllOf.

        Specify a fallback language to use when sending WhatsApp message template using the short hand syntax. Defaults to en_US. See WhatsApp documentation for more info.  # noqa: E501

        :param hsm_fallback_language: The hsm_fallback_language of this WhatsAppUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(hsm_fallback_language) is Undefined:
            hsm_fallback_language = None
            self.nulls.discard("hsm_fallback_language")
        elif hsm_fallback_language is None:
            self.nulls.add("hsm_fallback_language")
        else:
            self.nulls.discard("hsm_fallback_language")

        self._hsm_fallback_language = hsm_fallback_language

    @property
    def account_id(self):
        """Gets the account_id of this WhatsAppUpdateAllOf.  # noqa: E501

        The business ID associated with the WhatsApp account. In combination with accountManagementAccessToken, it’s used for Message Template Reconstruction.  # noqa: E501

        :return: The account_id of this WhatsAppUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WhatsAppUpdateAllOf.

        The business ID associated with the WhatsApp account. In combination with accountManagementAccessToken, it’s used for Message Template Reconstruction.  # noqa: E501

        :param account_id: The account_id of this WhatsAppUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(account_id) is Undefined:
            account_id = None
            self.nulls.discard("account_id")
        elif account_id is None:
            self.nulls.add("account_id")
        else:
            self.nulls.discard("account_id")

        self._account_id = account_id

    @property
    def account_management_access_token(self):
        """Gets the account_management_access_token of this WhatsAppUpdateAllOf.  # noqa: E501

        An access token associated with the accountId used to query the WhatsApp Account Management API. In combination with accountId, it’s used for Message Template Reconstruction.  # noqa: E501

        :return: The account_management_access_token of this WhatsAppUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_management_access_token

    @account_management_access_token.setter
    def account_management_access_token(self, account_management_access_token):
        """Sets the account_management_access_token of this WhatsAppUpdateAllOf.

        An access token associated with the accountId used to query the WhatsApp Account Management API. In combination with accountId, it’s used for Message Template Reconstruction.  # noqa: E501

        :param account_management_access_token: The account_management_access_token of this WhatsAppUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(account_management_access_token) is Undefined:
            account_management_access_token = None
            self.nulls.discard("account_management_access_token")
        elif account_management_access_token is None:
            self.nulls.add("account_management_access_token")
        else:
            self.nulls.discard("account_management_access_token")

        self._account_management_access_token = account_management_access_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WhatsAppUpdateAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WhatsAppUpdateAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class QuotedMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'message': 'Message',
        'external_message_id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'message': 'message',
        'external_message_id': 'externalMessageId'
    }

    nulls = set()

    discriminator_value_class_map = {
    }

    def __init__(self, type='externalMessageId', message=None, external_message_id=None, local_vars_configuration=None):  # noqa: E501
        """QuotedMessage - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._message = None
        self._external_message_id = None
        self.discriminator = 'type'

        self.type = type
        if message is not None:
            self.message = message
        if external_message_id is not None:
            self.external_message_id = external_message_id

    @property
    def type(self):
        """Gets the type of this QuotedMessage.  # noqa: E501

        The type of quotedMessage - `externalMessageId` if no Sunshine Conversations message matched the quoted message.  # noqa: E501

        :return: The type of this QuotedMessage.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this QuotedMessage.

        The type of quotedMessage - `externalMessageId` if no Sunshine Conversations message matched the quoted message.  # noqa: E501

        :param type: The type of this QuotedMessage.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def message(self):
        """Gets the message of this QuotedMessage.  # noqa: E501


        :return: The message of this QuotedMessage.  # noqa: E501
        :rtype: Message
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this QuotedMessage.


        :param message: The message of this QuotedMessage.  # noqa: E501
        :type: Message
        """

        self._message = message

    @property
    def external_message_id(self):
        """Gets the external_message_id of this QuotedMessage.  # noqa: E501

        The external message Id of the quoted message.  # noqa: E501

        :return: The external_message_id of this QuotedMessage.  # noqa: E501
        :rtype: str
        """
        return self._external_message_id

    @external_message_id.setter
    def external_message_id(self, external_message_id):
        """Sets the external_message_id of this QuotedMessage.

        The external message Id of the quoted message.  # noqa: E501

        :param external_message_id: The external_message_id of this QuotedMessage.  # noqa: E501
        :type: str
        """

        self._external_message_id = external_message_id

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        if self.discriminator is None:
            return
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuotedMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuotedMessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class Author(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'subtypes': 'list[str]',
        'user_id': 'str',
        'user_external_id': 'str',
        'display_name': 'str',
        'avatar_url': 'str'
    }

    attribute_map = {
        'type': 'type',
        'subtypes': 'subtypes',
        'user_id': 'userId',
        'user_external_id': 'userExternalId',
        'display_name': 'displayName',
        'avatar_url': 'avatarUrl'
    }

    nulls = set()

    def __init__(self, type=None, subtypes=None, user_id=None, user_external_id=None, display_name=None, avatar_url=None, local_vars_configuration=None):  # noqa: E501
        """Author - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._subtypes = None
        self._user_id = None
        self._user_external_id = None
        self._display_name = None
        self._avatar_url = None
        self.discriminator = None

        self.type = type
        if subtypes is not None:
            self.subtypes = subtypes
        if user_id is not None:
            self.user_id = user_id
        if user_external_id is not None:
            self.user_external_id = user_external_id
        if display_name is not None:
            self.display_name = display_name
        if avatar_url is not None:
            self.avatar_url = avatar_url

    @property
    def type(self):
        """Gets the type of this Author.  # noqa: E501

        The author type. Either \"user\" (representing the end user)  or \"business\" (sent on behalf of the business).   # noqa: E501

        :return: The type of this Author.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Author.

        The author type. Either \"user\" (representing the end user)  or \"business\" (sent on behalf of the business).   # noqa: E501

        :param type: The type of this Author.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["business", "user"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def subtypes(self):
        """Gets the subtypes of this Author.  # noqa: E501

        A string array that indicates the author's subtypes. Messages from \"business\" type with an \"AI\" subtype  are generated by AI and a disclaimer is appended to the text of the message sent to the customer.  For third-party channels, the disclaimer is applied for image, file, and text message types.   # noqa: E501

        :return: The subtypes of this Author.  # noqa: E501
        :rtype: list[str]
        """
        return self._subtypes

    @subtypes.setter
    def subtypes(self, subtypes):
        """Sets the subtypes of this Author.

        A string array that indicates the author's subtypes. Messages from \"business\" type with an \"AI\" subtype  are generated by AI and a disclaimer is appended to the text of the message sent to the customer.  For third-party channels, the disclaimer is applied for image, file, and text message types.   # noqa: E501

        :param subtypes: The subtypes of this Author.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["AI"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(subtypes).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `subtypes` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(subtypes) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._subtypes = subtypes

    @property
    def user_id(self):
        """Gets the user_id of this Author.  # noqa: E501

        The id of the user. Only supported when `type` is user.  # noqa: E501

        :return: The user_id of this Author.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Author.

        The id of the user. Only supported when `type` is user.  # noqa: E501

        :param user_id: The user_id of this Author.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_external_id(self):
        """Gets the user_external_id of this Author.  # noqa: E501

        The externalId of the user. Only supported when `type` is user.  # noqa: E501

        :return: The user_external_id of this Author.  # noqa: E501
        :rtype: str
        """
        return self._user_external_id

    @user_external_id.setter
    def user_external_id(self, user_external_id):
        """Sets the user_external_id of this Author.

        The externalId of the user. Only supported when `type` is user.  # noqa: E501

        :param user_external_id: The user_external_id of this Author.  # noqa: E501
        :type: str
        """

        self._user_external_id = user_external_id

    @property
    def display_name(self):
        """Gets the display_name of this Author.  # noqa: E501

        The display name of the message author.  # noqa: E501

        :return: The display_name of this Author.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Author.

        The display name of the message author.  # noqa: E501

        :param display_name: The display_name of this Author.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def avatar_url(self):
        """Gets the avatar_url of this Author.  # noqa: E501

        A custom message icon URL. The image must be JPG, PNG, or GIF format.  # noqa: E501

        :return: The avatar_url of this Author.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this Author.

        A custom message icon URL. The image must be JPG, PNG, or GIF format.  # noqa: E501

        :param avatar_url: The avatar_url of this Author.  # noqa: E501
        :type: str
        """

        self._avatar_url = avatar_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Author):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Author):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class Participant(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'unread_count': 'int',
        'client_associations': 'list[ClientAssociation]',
        'user_external_id': 'str',
        'last_read': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'unread_count': 'unreadCount',
        'client_associations': 'clientAssociations',
        'user_external_id': 'userExternalId',
        'last_read': 'lastRead'
    }

    nulls = set()

    def __init__(self, id=None, user_id=None, unread_count=None, client_associations=None, user_external_id=Undefined(), last_read=Undefined(), local_vars_configuration=None):  # noqa: E501
        """Participant - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._unread_count = None
        self._client_associations = None
        self._user_external_id = None
        self._last_read = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if unread_count is not None:
            self.unread_count = unread_count
        if client_associations is not None:
            self.client_associations = client_associations
        self.user_external_id = user_external_id
        self.last_read = last_read

    @property
    def id(self):
        """Gets the id of this Participant.  # noqa: E501

        The unique ID of the participant.  # noqa: E501

        :return: The id of this Participant.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Participant.

        The unique ID of the participant.  # noqa: E501

        :param id: The id of this Participant.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this Participant.  # noqa: E501

        The id of the associated user.  # noqa: E501

        :return: The user_id of this Participant.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Participant.

        The id of the associated user.  # noqa: E501

        :param user_id: The user_id of this Participant.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def unread_count(self):
        """Gets the unread_count of this Participant.  # noqa: E501

        Number of messages the user has not yet read.  # noqa: E501

        :return: The unread_count of this Participant.  # noqa: E501
        :rtype: int
        """
        return self._unread_count

    @unread_count.setter
    def unread_count(self, unread_count):
        """Sets the unread_count of this Participant.

        Number of messages the user has not yet read.  # noqa: E501

        :param unread_count: The unread_count of this Participant.  # noqa: E501
        :type: int
        """

        self._unread_count = unread_count

    @property
    def client_associations(self):
        """Gets the client_associations of this Participant.  # noqa: E501

        Represents the clients that are active in the conversation for a particular user. A participant can have multiple clientAssociations in the case of channel transfer, business initiated conversations, or identified users. The order of the array indicates how recently a client has interacted with the conversation, with the most recent client first. The first item in the array is considered to be the user's primary client for that conversation, and will be selected first for message delivery.   # noqa: E501

        :return: The client_associations of this Participant.  # noqa: E501
        :rtype: list[ClientAssociation]
        """
        return self._client_associations

    @client_associations.setter
    def client_associations(self, client_associations):
        """Sets the client_associations of this Participant.

        Represents the clients that are active in the conversation for a particular user. A participant can have multiple clientAssociations in the case of channel transfer, business initiated conversations, or identified users. The order of the array indicates how recently a client has interacted with the conversation, with the most recent client first. The first item in the array is considered to be the user's primary client for that conversation, and will be selected first for message delivery.   # noqa: E501

        :param client_associations: The client_associations of this Participant.  # noqa: E501
        :type: list[ClientAssociation]
        """

        self._client_associations = client_associations

    @property
    def user_external_id(self):
        """Gets the user_external_id of this Participant.  # noqa: E501

        The externalId of the associated user.  # noqa: E501

        :return: The user_external_id of this Participant.  # noqa: E501
        :rtype: str
        """
        return self._user_external_id

    @user_external_id.setter
    def user_external_id(self, user_external_id):
        """Sets the user_external_id of this Participant.

        The externalId of the associated user.  # noqa: E501

        :param user_external_id: The user_external_id of this Participant.  # noqa: E501
        :type: str
        """
        if type(user_external_id) is Undefined:
            user_external_id = None
            self.nulls.discard("user_external_id")
        elif user_external_id is None:
            self.nulls.add("user_external_id")
        else:
            self.nulls.discard("user_external_id")

        self._user_external_id = user_external_id

    @property
    def last_read(self):
        """Gets the last_read of this Participant.  # noqa: E501

        A datetime string with the format YYYY-MM-DDThh:mm:ss.SSSZ representing the latest message the user has read.  # noqa: E501

        :return: The last_read of this Participant.  # noqa: E501
        :rtype: str
        """
        return self._last_read

    @last_read.setter
    def last_read(self, last_read):
        """Sets the last_read of this Participant.

        A datetime string with the format YYYY-MM-DDThh:mm:ss.SSSZ representing the latest message the user has read.  # noqa: E501

        :param last_read: The last_read of this Participant.  # noqa: E501
        :type: str
        """
        if type(last_read) is Undefined:
            last_read = None
            self.nulls.discard("last_read")
        elif last_read is None:
            self.nulls.add("last_read")
        else:
            self.nulls.discard("last_read")

        self._last_read = last_read

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Participant):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Participant):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class AndroidUpdateAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'project_id': 'str',
        'client_email': 'str',
        'private_key': 'str',
        'server_key': 'str',
        'sender_id': 'str',
        'can_user_create_more_conversations': 'bool'
    }

    attribute_map = {
        'project_id': 'projectId',
        'client_email': 'clientEmail',
        'private_key': 'privateKey',
        'server_key': 'serverKey',
        'sender_id': 'senderId',
        'can_user_create_more_conversations': 'canUserCreateMoreConversations'
    }

    nulls = set()

    def __init__(self, project_id=Undefined(), client_email=Undefined(), private_key=Undefined(), server_key=Undefined(), sender_id=Undefined(), can_user_create_more_conversations=None, local_vars_configuration=None):  # noqa: E501
        """AndroidUpdateAllOf - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._project_id = None
        self._client_email = None
        self._private_key = None
        self._server_key = None
        self._sender_id = None
        self._can_user_create_more_conversations = None
        self.discriminator = None

        self.project_id = project_id
        self.client_email = client_email
        self.private_key = private_key
        self.server_key = server_key
        self.sender_id = sender_id
        if can_user_create_more_conversations is not None:
            self.can_user_create_more_conversations = can_user_create_more_conversations

    @property
    def project_id(self):
        """Gets the project_id of this AndroidUpdateAllOf.  # noqa: E501

        Your project ID from your generated private key file.  # noqa: E501

        :return: The project_id of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this AndroidUpdateAllOf.

        Your project ID from your generated private key file.  # noqa: E501

        :param project_id: The project_id of this AndroidUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(project_id) is Undefined:
            project_id = None
            self.nulls.discard("project_id")
        elif project_id is None:
            self.nulls.add("project_id")
        else:
            self.nulls.discard("project_id")
        if (self.local_vars_configuration.client_side_validation and
                project_id is not None and len(project_id) < 1):
            raise ValueError("Invalid value for `project_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._project_id = project_id

    @property
    def client_email(self):
        """Gets the client_email of this AndroidUpdateAllOf.  # noqa: E501

        Your client email from your generated private key file.  # noqa: E501

        :return: The client_email of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._client_email

    @client_email.setter
    def client_email(self, client_email):
        """Sets the client_email of this AndroidUpdateAllOf.

        Your client email from your generated private key file.  # noqa: E501

        :param client_email: The client_email of this AndroidUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(client_email) is Undefined:
            client_email = None
            self.nulls.discard("client_email")
        elif client_email is None:
            self.nulls.add("client_email")
        else:
            self.nulls.discard("client_email")
        if (self.local_vars_configuration.client_side_validation and
                client_email is not None and len(client_email) < 1):
            raise ValueError("Invalid value for `client_email`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_email = client_email

    @property
    def private_key(self):
        """Gets the private_key of this AndroidUpdateAllOf.  # noqa: E501

        Your private key from your generated private key file.  # noqa: E501

        :return: The private_key of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this AndroidUpdateAllOf.

        Your private key from your generated private key file.  # noqa: E501

        :param private_key: The private_key of this AndroidUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(private_key) is Undefined:
            private_key = None
            self.nulls.discard("private_key")
        elif private_key is None:
            self.nulls.add("private_key")
        else:
            self.nulls.discard("private_key")
        if (self.local_vars_configuration.client_side_validation and
                private_key is not None and len(private_key) < 1):
            raise ValueError("Invalid value for `private_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._private_key = private_key

    @property
    def server_key(self):
        """Gets the server_key of this AndroidUpdateAllOf.  # noqa: E501

        Your server key from the fcm console.  # noqa: E501

        :return: The server_key of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._server_key

    @server_key.setter
    def server_key(self, server_key):
        """Sets the server_key of this AndroidUpdateAllOf.

        Your server key from the fcm console.  # noqa: E501

        :param server_key: The server_key of this AndroidUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(server_key) is Undefined:
            server_key = None
            self.nulls.discard("server_key")
        elif server_key is None:
            self.nulls.add("server_key")
        else:
            self.nulls.discard("server_key")
        if (self.local_vars_configuration.client_side_validation and
                server_key is not None and len(server_key) < 1):
            raise ValueError("Invalid value for `server_key`, length must be greater than or equal to `1`")  # noqa: E501

        self._server_key = server_key

    @property
    def sender_id(self):
        """Gets the sender_id of this AndroidUpdateAllOf.  # noqa: E501

        Your sender id from the fcm console.  # noqa: E501

        :return: The sender_id of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: str
        """
        return self._sender_id

    @sender_id.setter
    def sender_id(self, sender_id):
        """Sets the sender_id of this AndroidUpdateAllOf.

        Your sender id from the fcm console.  # noqa: E501

        :param sender_id: The sender_id of this AndroidUpdateAllOf.  # noqa: E501
        :type: str
        """
        if type(sender_id) is Undefined:
            sender_id = None
            self.nulls.discard("sender_id")
        elif sender_id is None:
            self.nulls.add("sender_id")
        else:
            self.nulls.discard("sender_id")
        if (self.local_vars_configuration.client_side_validation and
                sender_id is not None and len(sender_id) < 1):
            raise ValueError("Invalid value for `sender_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._sender_id = sender_id

    @property
    def can_user_create_more_conversations(self):
        """Gets the can_user_create_more_conversations of this AndroidUpdateAllOf.  # noqa: E501

        Allows users to create more than one conversation on the android integration.  # noqa: E501

        :return: The can_user_create_more_conversations of this AndroidUpdateAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._can_user_create_more_conversations

    @can_user_create_more_conversations.setter
    def can_user_create_more_conversations(self, can_user_create_more_conversations):
        """Sets the can_user_create_more_conversations of this AndroidUpdateAllOf.

        Allows users to create more than one conversation on the android integration.  # noqa: E501

        :param can_user_create_more_conversations: The can_user_create_more_conversations of this AndroidUpdateAllOf.  # noqa: E501
        :type: bool
        """

        self._can_user_create_more_conversations = can_user_create_more_conversations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AndroidUpdateAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AndroidUpdateAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "14.3.4"

# import apis into sdk package
from sunshine_conversations_client.api.activities_api import ActivitiesApi
from sunshine_conversations_client.api.app_keys_api import AppKeysApi
from sunshine_conversations_client.api.apps_api import AppsApi
from sunshine_conversations_client.api.attachments_api import AttachmentsApi
from sunshine_conversations_client.api.clients_api import ClientsApi
from sunshine_conversations_client.api.conversations_api import ConversationsApi
from sunshine_conversations_client.api.custom_integration_api_keys_api import CustomIntegrationApiKeysApi
from sunshine_conversations_client.api.devices_api import DevicesApi
from sunshine_conversations_client.api.integrations_api import IntegrationsApi
from sunshine_conversations_client.api.messages_api import MessagesApi
from sunshine_conversations_client.api.o_auth_endpoints_api import OAuthEndpointsApi
from sunshine_conversations_client.api.participants_api import ParticipantsApi
from sunshine_conversations_client.api.switchboard_actions_api import SwitchboardActionsApi
from sunshine_conversations_client.api.switchboard_integrations_api import SwitchboardIntegrationsApi
from sunshine_conversations_client.api.switchboards_api import SwitchboardsApi
from sunshine_conversations_client.api.users_api import UsersApi
from sunshine_conversations_client.api.webhooks_api import WebhooksApi

# import ApiClient
from sunshine_conversations_client.api_client import ApiClient
from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.exceptions import OpenApiException
from sunshine_conversations_client.exceptions import ApiTypeError
from sunshine_conversations_client.exceptions import ApiValueError
from sunshine_conversations_client.exceptions import ApiKeyError
from sunshine_conversations_client.exceptions import ApiException
# import models into sdk package
from sunshine_conversations_client.model.accept_control_body import AcceptControlBody
from sunshine_conversations_client.model.action import Action
from sunshine_conversations_client.model.action_subset import ActionSubset
from sunshine_conversations_client.model.activity import Activity
from sunshine_conversations_client.model.activity_all_of import ActivityAllOf
from sunshine_conversations_client.model.activity_message import ActivityMessage
from sunshine_conversations_client.model.activity_post import ActivityPost
from sunshine_conversations_client.model.activity_post_all_of import ActivityPostAllOf
from sunshine_conversations_client.model.activity_types import ActivityTypes
from sunshine_conversations_client.model.android import Android
from sunshine_conversations_client.model.android_all_of import AndroidAllOf
from sunshine_conversations_client.model.android_update import AndroidUpdate
from sunshine_conversations_client.model.android_update_all_of import AndroidUpdateAllOf
from sunshine_conversations_client.model.api_key import ApiKey
from sunshine_conversations_client.model.app import App
from sunshine_conversations_client.model.app_create_body import AppCreateBody
from sunshine_conversations_client.model.app_key import AppKey
from sunshine_conversations_client.model.app_key_create_body import AppKeyCreateBody
from sunshine_conversations_client.model.app_key_list_response import AppKeyListResponse
from sunshine_conversations_client.model.app_key_response import AppKeyResponse
from sunshine_conversations_client.model.app_list_filter import AppListFilter
from sunshine_conversations_client.model.app_list_response import AppListResponse
from sunshine_conversations_client.model.app_response import AppResponse
from sunshine_conversations_client.model.app_settings import AppSettings
from sunshine_conversations_client.model.app_sub_schema import AppSubSchema
from sunshine_conversations_client.model.app_update_body import AppUpdateBody
from sunshine_conversations_client.model.apple import Apple
from sunshine_conversations_client.model.apple_all_of import AppleAllOf
from sunshine_conversations_client.model.apple_message_override_payload import AppleMessageOverridePayload
from sunshine_conversations_client.model.apple_update import AppleUpdate
from sunshine_conversations_client.model.apple_update_all_of import AppleUpdateAllOf
from sunshine_conversations_client.model.attachment_delete_body import AttachmentDeleteBody
from sunshine_conversations_client.model.attachment_response import AttachmentResponse
from sunshine_conversations_client.model.attachment_schema import AttachmentSchema
from sunshine_conversations_client.model.attachment_upload_body import AttachmentUploadBody
from sunshine_conversations_client.model.author import Author
from sunshine_conversations_client.model.author_webhook import AuthorWebhook
from sunshine_conversations_client.model.buy import Buy
from sunshine_conversations_client.model.campaign import Campaign
from sunshine_conversations_client.model.carousel_message import CarouselMessage
from sunshine_conversations_client.model.carousel_message_display_settings import CarouselMessageDisplaySettings
from sunshine_conversations_client.model.client import Client
from sunshine_conversations_client.model.client_add_event import ClientAddEvent
from sunshine_conversations_client.model.client_add_event_all_of import ClientAddEventAllOf
from sunshine_conversations_client.model.client_add_event_all_of_payload import ClientAddEventAllOfPayload
from sunshine_conversations_client.model.client_association import ClientAssociation
from sunshine_conversations_client.model.client_create import ClientCreate
from sunshine_conversations_client.model.client_list_response import ClientListResponse
from sunshine_conversations_client.model.client_remove_event import ClientRemoveEvent
from sunshine_conversations_client.model.client_remove_event_all_of import ClientRemoveEventAllOf
from sunshine_conversations_client.model.client_remove_event_all_of_payload import ClientRemoveEventAllOfPayload
from sunshine_conversations_client.model.client_response import ClientResponse
from sunshine_conversations_client.model.client_type import ClientType
from sunshine_conversations_client.model.client_update_event import ClientUpdateEvent
from sunshine_conversations_client.model.client_update_event_all_of import ClientUpdateEventAllOf
from sunshine_conversations_client.model.client_update_event_all_of_payload import ClientUpdateEventAllOfPayload
from sunshine_conversations_client.model.confirmation import Confirmation
from sunshine_conversations_client.model.content import Content
from sunshine_conversations_client.model.conversation import Conversation
from sunshine_conversations_client.model.conversation_all_of import ConversationAllOf
from sunshine_conversations_client.model.conversation_create_body import ConversationCreateBody
from sunshine_conversations_client.model.conversation_create_event import ConversationCreateEvent
from sunshine_conversations_client.model.conversation_create_event_all_of import ConversationCreateEventAllOf
from sunshine_conversations_client.model.conversation_create_event_all_of_payload import ConversationCreateEventAllOfPayload
from sunshine_conversations_client.model.conversation_join_event import ConversationJoinEvent
from sunshine_conversations_client.model.conversation_join_event_all_of import ConversationJoinEventAllOf
from sunshine_conversations_client.model.conversation_join_event_all_of_payload import ConversationJoinEventAllOfPayload
from sunshine_conversations_client.model.conversation_leave_event import ConversationLeaveEvent
from sunshine_conversations_client.model.conversation_leave_event_all_of import ConversationLeaveEventAllOf
from sunshine_conversations_client.model.conversation_leave_event_all_of_payload import ConversationLeaveEventAllOfPayload
from sunshine_conversations_client.model.conversation_list_filter import ConversationListFilter
from sunshine_conversations_client.model.conversation_list_response import ConversationListResponse
from sunshine_conversations_client.model.conversation_message_delivery_channel_event import ConversationMessageDeliveryChannelEvent
from sunshine_conversations_client.model.conversation_message_delivery_channel_event_all_of import ConversationMessageDeliveryChannelEventAllOf
from sunshine_conversations_client.model.conversation_message_delivery_failure_event import ConversationMessageDeliveryFailureEvent
from sunshine_conversations_client.model.conversation_message_delivery_failure_event_all_of import ConversationMessageDeliveryFailureEventAllOf
from sunshine_conversations_client.model.conversation_message_delivery_payload import ConversationMessageDeliveryPayload
from sunshine_conversations_client.model.conversation_message_delivery_payload_destination import ConversationMessageDeliveryPayloadDestination
from sunshine_conversations_client.model.conversation_message_delivery_payload_external_messages import ConversationMessageDeliveryPayloadExternalMessages
from sunshine_conversations_client.model.conversation_message_delivery_payload_message import ConversationMessageDeliveryPayloadMessage
from sunshine_conversations_client.model.conversation_message_delivery_user_event import ConversationMessageDeliveryUserEvent
from sunshine_conversations_client.model.conversation_message_event import ConversationMessageEvent
from sunshine_conversations_client.model.conversation_message_event_all_of import ConversationMessageEventAllOf
from sunshine_conversations_client.model.conversation_message_event_all_of_payload import ConversationMessageEventAllOfPayload
from sunshine_conversations_client.model.conversation_postback_event import ConversationPostbackEvent
from sunshine_conversations_client.model.conversation_postback_event_all_of import ConversationPostbackEventAllOf
from sunshine_conversations_client.model.conversation_postback_event_all_of_payload import ConversationPostbackEventAllOfPayload
from sunshine_conversations_client.model.conversation_read_event import ConversationReadEvent
from sunshine_conversations_client.model.conversation_read_event_all_of import ConversationReadEventAllOf
from sunshine_conversations_client.model.conversation_read_event_all_of_payload import ConversationReadEventAllOfPayload
from sunshine_conversations_client.model.conversation_referral_event import ConversationReferralEvent
from sunshine_conversations_client.model.conversation_referral_event_all_of import ConversationReferralEventAllOf
from sunshine_conversations_client.model.conversation_referral_event_all_of_payload import ConversationReferralEventAllOfPayload
from sunshine_conversations_client.model.conversation_remove_event import ConversationRemoveEvent
from sunshine_conversations_client.model.conversation_remove_event_all_of import ConversationRemoveEventAllOf
from sunshine_conversations_client.model.conversation_remove_event_all_of_payload import ConversationRemoveEventAllOfPayload
from sunshine_conversations_client.model.conversation_response import ConversationResponse
from sunshine_conversations_client.model.conversation_truncated import ConversationTruncated
from sunshine_conversations_client.model.conversation_type import ConversationType
from sunshine_conversations_client.model.conversation_typing_event import ConversationTypingEvent
from sunshine_conversations_client.model.conversation_typing_event_all_of import ConversationTypingEventAllOf
from sunshine_conversations_client.model.conversation_typing_event_all_of_payload import ConversationTypingEventAllOfPayload
from sunshine_conversations_client.model.conversation_update_body import ConversationUpdateBody
from sunshine_conversations_client.model.custom import Custom
from sunshine_conversations_client.model.custom_all_of import CustomAllOf
from sunshine_conversations_client.model.custom_update import CustomUpdate
from sunshine_conversations_client.model.default_responder import DefaultResponder
from sunshine_conversations_client.model.default_responder_default_responder import DefaultResponderDefaultResponder
from sunshine_conversations_client.model.default_responder_id import DefaultResponderId
from sunshine_conversations_client.model.destination import Destination
from sunshine_conversations_client.model.device import Device
from sunshine_conversations_client.model.device_list_response import DeviceListResponse
from sunshine_conversations_client.model.device_response import DeviceResponse
from sunshine_conversations_client.model.download_message_ref_body import DownloadMessageRefBody
from sunshine_conversations_client.model.download_message_ref_body_all_of import DownloadMessageRefBodyAllOf
from sunshine_conversations_client.model.download_message_ref_body_all_of_apple import DownloadMessageRefBodyAllOfApple
from sunshine_conversations_client.model.download_message_ref_body_all_of_apple_interactive_data_ref import DownloadMessageRefBodyAllOfAppleInteractiveDataRef
from sunshine_conversations_client.model.event_sub_schema import EventSubSchema
from sunshine_conversations_client.model.extra_channel_options import ExtraChannelOptions
from sunshine_conversations_client.model.extra_channel_options_messenger import ExtraChannelOptionsMessenger
from sunshine_conversations_client.model.field import Field
from sunshine_conversations_client.model.file_message import FileMessage
from sunshine_conversations_client.model.form_message import FormMessage
from sunshine_conversations_client.model.form_message_field import FormMessageField
from sunshine_conversations_client.model.form_message_field_all_of import FormMessageFieldAllOf
from sunshine_conversations_client.model.form_response_message import FormResponseMessage
from sunshine_conversations_client.model.form_response_message_field import FormResponseMessageField
from sunshine_conversations_client.model.form_response_message_field_all_of import FormResponseMessageFieldAllOf
from sunshine_conversations_client.model.identity import Identity
from sunshine_conversations_client.model.image_message import ImageMessage
from sunshine_conversations_client.model.inline_object import InlineObject
from sunshine_conversations_client.model.instagram import Instagram
from sunshine_conversations_client.model.instagram_all_of import InstagramAllOf
from sunshine_conversations_client.model.instagram_update import InstagramUpdate
from sunshine_conversations_client.model.instagram_update_all_of import InstagramUpdateAllOf
from sunshine_conversations_client.model.integration import Integration
from sunshine_conversations_client.model.integration_api_key import IntegrationApiKey
from sunshine_conversations_client.model.integration_api_key_list_response import IntegrationApiKeyListResponse
from sunshine_conversations_client.model.integration_api_key_response import IntegrationApiKeyResponse
from sunshine_conversations_client.model.integration_id import IntegrationId
from sunshine_conversations_client.model.integration_list_filter import IntegrationListFilter
from sunshine_conversations_client.model.integration_list_response import IntegrationListResponse
from sunshine_conversations_client.model.integration_response import IntegrationResponse
from sunshine_conversations_client.model.integration_type import IntegrationType
from sunshine_conversations_client.model.integration_update import IntegrationUpdate
from sunshine_conversations_client.model.integration_update_base import IntegrationUpdateBase
from sunshine_conversations_client.model.ios import Ios
from sunshine_conversations_client.model.ios_all_of import IosAllOf
from sunshine_conversations_client.model.ios_update import IosUpdate
from sunshine_conversations_client.model.ios_update_all_of import IosUpdateAllOf
from sunshine_conversations_client.model.item import Item
from sunshine_conversations_client.model.line import Line
from sunshine_conversations_client.model.line_all_of import LineAllOf
from sunshine_conversations_client.model.line_update import LineUpdate
from sunshine_conversations_client.model.link import Link
from sunshine_conversations_client.model.links import Links
from sunshine_conversations_client.model.list_message import ListMessage
from sunshine_conversations_client.model.location_message import LocationMessage
from sunshine_conversations_client.model.location_message_coordinates import LocationMessageCoordinates
from sunshine_conversations_client.model.location_message_location import LocationMessageLocation
from sunshine_conversations_client.model.location_request import LocationRequest
from sunshine_conversations_client.model.mailgun import Mailgun
from sunshine_conversations_client.model.mailgun_all_of import MailgunAllOf
from sunshine_conversations_client.model.mailgun_update import MailgunUpdate
from sunshine_conversations_client.model.mailgun_update_all_of import MailgunUpdateAllOf
from sunshine_conversations_client.model.match_criteria import MatchCriteria
from sunshine_conversations_client.model.match_criteria_base import MatchCriteriaBase
from sunshine_conversations_client.model.match_criteria_mailgun import MatchCriteriaMailgun
from sunshine_conversations_client.model.match_criteria_mailgun_all_of import MatchCriteriaMailgunAllOf
from sunshine_conversations_client.model.match_criteria_messagebird import MatchCriteriaMessagebird
from sunshine_conversations_client.model.match_criteria_messagebird_all_of import MatchCriteriaMessagebirdAllOf
from sunshine_conversations_client.model.match_criteria_twilio import MatchCriteriaTwilio
from sunshine_conversations_client.model.match_criteria_twilio_all_of import MatchCriteriaTwilioAllOf
from sunshine_conversations_client.model.match_criteria_whatsapp import MatchCriteriaWhatsapp
from sunshine_conversations_client.model.match_criteria_whatsapp_all_of import MatchCriteriaWhatsappAllOf
from sunshine_conversations_client.model.message import Message
from sunshine_conversations_client.model.message_bird_update import MessageBirdUpdate
from sunshine_conversations_client.model.message_list_response import MessageListResponse
from sunshine_conversations_client.model.message_override import MessageOverride
from sunshine_conversations_client.model.message_override_apple import MessageOverrideApple
from sunshine_conversations_client.model.message_override_line import MessageOverrideLine
from sunshine_conversations_client.model.message_override_messenger import MessageOverrideMessenger
from sunshine_conversations_client.model.message_override_payload import MessageOverridePayload
from sunshine_conversations_client.model.message_override_whatsapp import MessageOverrideWhatsapp
from sunshine_conversations_client.model.message_post import MessagePost
from sunshine_conversations_client.model.message_post_response import MessagePostResponse
from sunshine_conversations_client.model.message_webhook import MessageWebhook
from sunshine_conversations_client.model.messagebird import Messagebird
from sunshine_conversations_client.model.messagebird_all_of import MessagebirdAllOf
from sunshine_conversations_client.model.messenger import Messenger
from sunshine_conversations_client.model.messenger_all_of import MessengerAllOf
from sunshine_conversations_client.model.messenger_update import MessengerUpdate
from sunshine_conversations_client.model.meta import Meta
from sunshine_conversations_client.model.offer_control_body import OfferControlBody
from sunshine_conversations_client.model.page import Page
from sunshine_conversations_client.model.participant import Participant
from sunshine_conversations_client.model.participant_join_body import ParticipantJoinBody
from sunshine_conversations_client.model.participant_leave_body import ParticipantLeaveBody
from sunshine_conversations_client.model.participant_leave_body_participant_id import ParticipantLeaveBodyParticipantId
from sunshine_conversations_client.model.participant_leave_body_user_external_id import ParticipantLeaveBodyUserExternalId
from sunshine_conversations_client.model.participant_leave_body_user_id import ParticipantLeaveBodyUserId
from sunshine_conversations_client.model.participant_list_response import ParticipantListResponse
from sunshine_conversations_client.model.participant_response import ParticipantResponse
from sunshine_conversations_client.model.participant_sub_schema import ParticipantSubSchema
from sunshine_conversations_client.model.participant_with_user_external_id import ParticipantWithUserExternalId
from sunshine_conversations_client.model.participant_with_user_id import ParticipantWithUserId
from sunshine_conversations_client.model.pass_control_body import PassControlBody
from sunshine_conversations_client.model.postback import Postback
from sunshine_conversations_client.model.postback_webhook import PostbackWebhook
from sunshine_conversations_client.model.prechat_capture import PrechatCapture
from sunshine_conversations_client.model.profile import Profile
from sunshine_conversations_client.model.quoted_message import QuotedMessage
from sunshine_conversations_client.model.quoted_message_external_message_id import QuotedMessageExternalMessageId
from sunshine_conversations_client.model.quoted_message_message import QuotedMessageMessage
from sunshine_conversations_client.model.referral import Referral
from sunshine_conversations_client.model.referral_details import ReferralDetails
from sunshine_conversations_client.model.reply import Reply
from sunshine_conversations_client.model.source import Source
from sunshine_conversations_client.model.source_webhook import SourceWebhook
from sunshine_conversations_client.model.source_with_campaign_webhook import SourceWithCampaignWebhook
from sunshine_conversations_client.model.source_with_campaign_webhook_all_of import SourceWithCampaignWebhookAllOf
from sunshine_conversations_client.model.status import Status
from sunshine_conversations_client.model.switchboard import Switchboard
from sunshine_conversations_client.model.switchboard_accept_control import SwitchboardAcceptControl
from sunshine_conversations_client.model.switchboard_accept_control_all_of import SwitchboardAcceptControlAllOf
from sunshine_conversations_client.model.switchboard_accept_control_all_of_payload import SwitchboardAcceptControlAllOfPayload
from sunshine_conversations_client.model.switchboard_accept_control_failure import SwitchboardAcceptControlFailure
from sunshine_conversations_client.model.switchboard_accept_control_failure_all_of import SwitchboardAcceptControlFailureAllOf
from sunshine_conversations_client.model.switchboard_accept_control_failure_all_of_payload import SwitchboardAcceptControlFailureAllOfPayload
from sunshine_conversations_client.model.switchboard_integration import SwitchboardIntegration
from sunshine_conversations_client.model.switchboard_integration_create_body import SwitchboardIntegrationCreateBody
from sunshine_conversations_client.model.switchboard_integration_list_response import SwitchboardIntegrationListResponse
from sunshine_conversations_client.model.switchboard_integration_response import SwitchboardIntegrationResponse
from sunshine_conversations_client.model.switchboard_integration_update_body import SwitchboardIntegrationUpdateBody
from sunshine_conversations_client.model.switchboard_integration_webhook import SwitchboardIntegrationWebhook
from sunshine_conversations_client.model.switchboard_list_response import SwitchboardListResponse
from sunshine_conversations_client.model.switchboard_offer_control import SwitchboardOfferControl
from sunshine_conversations_client.model.switchboard_offer_control_all_of import SwitchboardOfferControlAllOf
from sunshine_conversations_client.model.switchboard_offer_control_all_of_payload import SwitchboardOfferControlAllOfPayload
from sunshine_conversations_client.model.switchboard_offer_control_failure import SwitchboardOfferControlFailure
from sunshine_conversations_client.model.switchboard_pass_control import SwitchboardPassControl
from sunshine_conversations_client.model.switchboard_pass_control_all_of import SwitchboardPassControlAllOf
from sunshine_conversations_client.model.switchboard_pass_control_all_of_payload import SwitchboardPassControlAllOfPayload
from sunshine_conversations_client.model.switchboard_pass_control_failure import SwitchboardPassControlFailure
from sunshine_conversations_client.model.switchboard_response import SwitchboardResponse
from sunshine_conversations_client.model.switchboard_update_body import SwitchboardUpdateBody
from sunshine_conversations_client.model.target import Target
from sunshine_conversations_client.model.telegram import Telegram
from sunshine_conversations_client.model.telegram_all_of import TelegramAllOf
from sunshine_conversations_client.model.telegram_update import TelegramUpdate
from sunshine_conversations_client.model.template_message import TemplateMessage
from sunshine_conversations_client.model.text_message import TextMessage
from sunshine_conversations_client.model.ticket_closed import TicketClosed
from sunshine_conversations_client.model.transfer_to_email import TransferToEmail
from sunshine_conversations_client.model.twilio import Twilio
from sunshine_conversations_client.model.twilio_all_of import TwilioAllOf
from sunshine_conversations_client.model.twilio_update import TwilioUpdate
from sunshine_conversations_client.model.twitter import Twitter
from sunshine_conversations_client.model.twitter_all_of import TwitterAllOf
from sunshine_conversations_client.model.twitter_update import TwitterUpdate
from sunshine_conversations_client.model.unity import Unity
from sunshine_conversations_client.model.unity_all_of import UnityAllOf
from sunshine_conversations_client.model.unity_update import UnityUpdate
from sunshine_conversations_client.model.unity_update_all_of import UnityUpdateAllOf
from sunshine_conversations_client.model.user import User
from sunshine_conversations_client.model.user_all_of import UserAllOf
from sunshine_conversations_client.model.user_create_body import UserCreateBody
from sunshine_conversations_client.model.user_merge_event import UserMergeEvent
from sunshine_conversations_client.model.user_merge_event_all_of import UserMergeEventAllOf
from sunshine_conversations_client.model.user_merge_event_all_of_payload import UserMergeEventAllOfPayload
from sunshine_conversations_client.model.user_merge_event_all_of_payload_merged_clients import UserMergeEventAllOfPayloadMergedClients
from sunshine_conversations_client.model.user_merge_event_all_of_payload_merged_conversations import UserMergeEventAllOfPayloadMergedConversations
from sunshine_conversations_client.model.user_merge_event_all_of_payload_merged_users import UserMergeEventAllOfPayloadMergedUsers
from sunshine_conversations_client.model.user_remove_event import UserRemoveEvent
from sunshine_conversations_client.model.user_remove_event_all_of import UserRemoveEventAllOf
from sunshine_conversations_client.model.user_remove_event_all_of_payload import UserRemoveEventAllOfPayload
from sunshine_conversations_client.model.user_response import UserResponse
from sunshine_conversations_client.model.user_truncated import UserTruncated
from sunshine_conversations_client.model.user_update_body import UserUpdateBody
from sunshine_conversations_client.model.user_update_event import UserUpdateEvent
from sunshine_conversations_client.model.user_update_event_all_of import UserUpdateEventAllOf
from sunshine_conversations_client.model.user_update_event_all_of_payload import UserUpdateEventAllOfPayload
from sunshine_conversations_client.model.viber import Viber
from sunshine_conversations_client.model.viber_all_of import ViberAllOf
from sunshine_conversations_client.model.viber_update import ViberUpdate
from sunshine_conversations_client.model.web import Web
from sunshine_conversations_client.model.web_all_of import WebAllOf
from sunshine_conversations_client.model.web_update import WebUpdate
from sunshine_conversations_client.model.web_update_all_of import WebUpdateAllOf
from sunshine_conversations_client.model.webhook import Webhook
from sunshine_conversations_client.model.webhook_body import WebhookBody
from sunshine_conversations_client.model.webhook_create_body import WebhookCreateBody
from sunshine_conversations_client.model.webhook_list_response import WebhookListResponse
from sunshine_conversations_client.model.webhook_response import WebhookResponse
from sunshine_conversations_client.model.webhook_sub_schema import WebhookSubSchema
from sunshine_conversations_client.model.webview import Webview
from sunshine_conversations_client.model.whats_app_update import WhatsAppUpdate
from sunshine_conversations_client.model.whats_app_update_all_of import WhatsAppUpdateAllOf
from sunshine_conversations_client.model.whatsapp import Whatsapp
from sunshine_conversations_client.model.whatsapp_all_of import WhatsappAllOf




# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sunshine_conversations_client.api_client import ApiClient
from sunshine_conversations_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AttachmentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_attachment(self, app_id, attachment_delete_body, **kwargs):  # noqa: E501
        """Delete Attachment  # noqa: E501

        Remove an attachment uploaded to Sunshine Conversations through the Upload attachment API. See [Attachments for Messages](#section/Attachments-for-Messages) to have attachments automatically deleted when deleting messages, conversations or users. <aside class=\"notice\">Note that deleted attachments can remain available on our CDN’s cache up to 15 minutes after the delete call.</aside>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment(app_id, attachment_delete_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str app_id: Identifies the app. (required)
        :param AttachmentDeleteBody attachment_delete_body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_attachment_with_http_info(app_id, attachment_delete_body, **kwargs)  # noqa: E501

    def delete_attachment_with_http_info(self, app_id, attachment_delete_body, **kwargs):  # noqa: E501
        """Delete Attachment  # noqa: E501

        Remove an attachment uploaded to Sunshine Conversations through the Upload attachment API. See [Attachments for Messages](#section/Attachments-for-Messages) to have attachments automatically deleted when deleting messages, conversations or users. <aside class=\"notice\">Note that deleted attachments can remain available on our CDN’s cache up to 15 minutes after the delete call.</aside>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_attachment_with_http_info(app_id, attachment_delete_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str app_id: Identifies the app. (required)
        :param AttachmentDeleteBody attachment_delete_body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'app_id',
            'attachment_delete_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_attachment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and ('app_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['app_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `delete_attachment`")  # noqa: E501
        # verify the required parameter 'attachment_delete_body' is set
        if self.api_client.client_side_validation and ('attachment_delete_body' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_delete_body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_delete_body` when calling `delete_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'app_id' in local_var_params:
            path_params['appId'] = local_var_params['app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attachment_delete_body' in local_var_params:
            body_params = local_var_params['attachment_delete_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v2/apps/{appId}/attachments/remove', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_attachment(self, app_id, access, source, **kwargs):  # noqa: E501
        """Upload Attachment  # noqa: E501

        Upload an attachment to Sunshine Conversations to use in future messages. Files are uploaded using the multipart/form-data content type. Use the returned mediaUrl to send a file, image or carousel message. <aside class=\"notice\">Note that Sunshine Conversations limits the size and type of file you can upload to the platform. See the <a href=\"https://docs.smooch.io/guide/validating-files\">file validation</a> guide for more details.</aside>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_attachment(app_id, access, source, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str app_id: Identifies the app. (required)
        :param str access: The access level for the attachment. Currently the only available access level is public. Private is not supported. (required)
        :param file source: (required)
        :param str _for: Specifies the intended container for the attachment, to enable automatic attachment deletion (on deletion of associated message, conversation or user). For now, only message is supported. See [Attachments for Messages](#section/Attachments-for-Messages) for details.
        :param str conversation_id: Links the attachment getting uploaded to the conversation ID.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AttachmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_attachment_with_http_info(app_id, access, source, **kwargs)  # noqa: E501

    def upload_attachment_with_http_info(self, app_id, access, source, **kwargs):  # noqa: E501
        """Upload Attachment  # noqa: E501

        Upload an attachment to Sunshine Conversations to use in future messages. Files are uploaded using the multipart/form-data content type. Use the returned mediaUrl to send a file, image or carousel message. <aside class=\"notice\">Note that Sunshine Conversations limits the size and type of file you can upload to the platform. See the <a href=\"https://docs.smooch.io/guide/validating-files\">file validation</a> guide for more details.</aside>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_attachment_with_http_info(app_id, access, source, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str app_id: Identifies the app. (required)
        :param str access: The access level for the attachment. Currently the only available access level is public. Private is not supported. (required)
        :param file source: (required)
        :param str _for: Specifies the intended container for the attachment, to enable automatic attachment deletion (on deletion of associated message, conversation or user). For now, only message is supported. See [Attachments for Messages](#section/Attachments-for-Messages) for details.
        :param str conversation_id: Links the attachment getting uploaded to the conversation ID.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AttachmentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'app_id',
            'access',
            'source',
            '_for',
            'conversation_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_attachment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and ('app_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['app_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `upload_attachment`")  # noqa: E501
        # verify the required parameter 'access' is set
        if self.api_client.client_side_validation and ('access' not in local_var_params or  # noqa: E501
                                                        local_var_params['access'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `access` when calling `upload_attachment`")  # noqa: E501
        # verify the required parameter 'source' is set
        if self.api_client.client_side_validation and ('source' not in local_var_params or  # noqa: E501
                                                        local_var_params['source'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `source` when calling `upload_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'app_id' in local_var_params:
            path_params['appId'] = local_var_params['app_id']  # noqa: E501

        query_params = []
        if 'access' in local_var_params and local_var_params['access'] is not None:  # noqa: E501
            query_params.append(('access', local_var_params['access']))  # noqa: E501
        if '_for' in local_var_params and local_var_params['_for'] is not None:  # noqa: E501
            query_params.append(('for', local_var_params['_for']))  # noqa: E501
        if 'conversation_id' in local_var_params and local_var_params['conversation_id'] is not None:  # noqa: E501
            query_params.append(('conversationId', local_var_params['conversation_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'source' in local_var_params:
            local_var_files['source'] = local_var_params['source']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v2/apps/{appId}/attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined

try:
    Integration = __import__("sunshine_conversations_client.model."+re.sub(r'(?<!^)(?=[A-Z])', '_', "Integration").lower(), fromlist=("Integration")).Integration
except ImportError:
    pass

class Telegram(Integration):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'token': 'str',
        'username': 'str',
        'bot_id': 'str',
        'default_responder_id': 'str',
        'default_responder': 'DefaultResponderDefaultResponder'
    }

    attribute_map = {
        'type': 'type',
        'token': 'token',
        'username': 'username',
        'bot_id': 'botId',
        'default_responder_id': 'defaultResponderId',
        'default_responder': 'defaultResponder'
    }

    nulls = set()

    def __init__(self, type='telegram', token=None, username=None, bot_id=None, default_responder_id=Undefined(), default_responder=None, local_vars_configuration=None, **kwargs):  # noqa: E501
        """Telegram - a model defined in OpenAPI"""  # noqa: E501
        super().__init__(**kwargs)

        if (super().openapi_types is not None):
            all_types = super().openapi_types.copy()
            all_types.update(self.openapi_types)
            self.openapi_types = all_types

        if (super().attribute_map is not None):
            all_attributes = super().attribute_map.copy()
            all_attributes.update(self.attribute_map)
            self.attribute_map = all_attributes
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._token = None
        self._username = None
        self._bot_id = None
        self._default_responder_id = None
        self._default_responder = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if token is not None:
            self.token = token
        if username is not None:
            self.username = username
        if bot_id is not None:
            self.bot_id = bot_id
        self.default_responder_id = default_responder_id
        if default_responder is not None:
            self.default_responder = default_responder

    @property
    def type(self):
        """Gets the type of this Telegram.  # noqa: E501

        To configure a Telegram integration, acquire the required information from the user and call the Create Integration endpoint.   # noqa: E501

        :return: The type of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Telegram.

        To configure a Telegram integration, acquire the required information from the user and call the Create Integration endpoint.   # noqa: E501

        :param type: The type of this Telegram.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def token(self):
        """Gets the token of this Telegram.  # noqa: E501

        Telegram Bot Token.  # noqa: E501

        :return: The token of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Telegram.

        Telegram Bot Token.  # noqa: E501

        :param token: The token of this Telegram.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and token is None:  # noqa: E501
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token is not None and len(token) < 1):
            raise ValueError("Invalid value for `token`, length must be greater than or equal to `1`")  # noqa: E501

        self._token = token

    @property
    def username(self):
        """Gets the username of this Telegram.  # noqa: E501

        Username of the botId  # noqa: E501

        :return: The username of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this Telegram.

        Username of the botId  # noqa: E501

        :param username: The username of this Telegram.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def bot_id(self):
        """Gets the bot_id of this Telegram.  # noqa: E501

        A human-friendly name used to identify the integration.  # noqa: E501

        :return: The bot_id of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """Sets the bot_id of this Telegram.

        A human-friendly name used to identify the integration.  # noqa: E501

        :param bot_id: The bot_id of this Telegram.  # noqa: E501
        :type: str
        """

        self._bot_id = bot_id

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this Telegram.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this Telegram.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this Telegram.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this Telegram.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def default_responder(self):
        """Gets the default_responder of this Telegram.  # noqa: E501


        :return: The default_responder of this Telegram.  # noqa: E501
        :rtype: DefaultResponderDefaultResponder
        """
        return self._default_responder

    @default_responder.setter
    def default_responder(self, default_responder):
        """Sets the default_responder of this Telegram.


        :param default_responder: The default_responder of this Telegram.  # noqa: E501
        :type: DefaultResponderDefaultResponder
        """

        self._default_responder = default_responder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Telegram):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Telegram):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class Device(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'type': 'str',
        'guid': 'str',
        'client_id': 'str',
        'status': 'str',
        'integration_id': 'str',
        'last_seen': 'str',
        'push_notification_token': 'str',
        'info': 'object',
        'app_version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'guid': 'guid',
        'client_id': 'clientId',
        'status': 'status',
        'integration_id': 'integrationId',
        'last_seen': 'lastSeen',
        'push_notification_token': 'pushNotificationToken',
        'info': 'info',
        'app_version': 'appVersion'
    }

    nulls = set()

    def __init__(self, id=None, type=None, guid=None, client_id=None, status=None, integration_id=None, last_seen=None, push_notification_token=Undefined(), info=Undefined(), app_version=Undefined(), local_vars_configuration=None):  # noqa: E501
        """Device - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._type = None
        self._guid = None
        self._client_id = None
        self._status = None
        self._integration_id = None
        self._last_seen = None
        self._push_notification_token = None
        self._info = None
        self._app_version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if guid is not None:
            self.guid = guid
        if client_id is not None:
            self.client_id = client_id
        if status is not None:
            self.status = status
        if integration_id is not None:
            self.integration_id = integration_id
        if last_seen is not None:
            self.last_seen = last_seen
        self.push_notification_token = push_notification_token
        self.info = info
        self.app_version = app_version

    @property
    def id(self):
        """Gets the id of this Device.  # noqa: E501

        The unique ID of the device.  # noqa: E501

        :return: The id of this Device.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Device.

        The unique ID of the device.  # noqa: E501

        :param id: The id of this Device.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this Device.  # noqa: E501

        The type of integration that the device represents.  # noqa: E501

        :return: The type of this Device.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Device.

        The type of integration that the device represents.  # noqa: E501

        :param type: The type of this Device.  # noqa: E501
        :type: str
        """
        allowed_values = ["android", "ios", "web"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def guid(self):
        """Gets the guid of this Device.  # noqa: E501

        A unique identifier for the device, generated client-side by the SDK.  # noqa: E501

        :return: The guid of this Device.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this Device.

        A unique identifier for the device, generated client-side by the SDK.  # noqa: E501

        :param guid: The guid of this Device.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def client_id(self):
        """Gets the client_id of this Device.  # noqa: E501

        The id of the client to which this device is associated.  # noqa: E501

        :return: The client_id of this Device.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this Device.

        The id of the client to which this device is associated.  # noqa: E501

        :param client_id: The client_id of this Device.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def status(self):
        """Gets the status of this Device.  # noqa: E501

        The device status. Indicates if the device will receive push notifications or not.  # noqa: E501

        :return: The status of this Device.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Device.

        The device status. Indicates if the device will receive push notifications or not.  # noqa: E501

        :param status: The status of this Device.  # noqa: E501
        :type: str
        """
        allowed_values = ["active", "inactive"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def integration_id(self):
        """Gets the integration_id of this Device.  # noqa: E501

        The ID of the integration that the device was created for.  # noqa: E501

        :return: The integration_id of this Device.  # noqa: E501
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this Device.

        The ID of the integration that the device was created for.  # noqa: E501

        :param integration_id: The integration_id of this Device.  # noqa: E501
        :type: str
        """

        self._integration_id = integration_id

    @property
    def last_seen(self):
        """Gets the last_seen of this Device.  # noqa: E501

        A datetime string with the format YYYY-MM-DDThh:mm:ss.SSSZ representing the last time the user interacted with this device.  # noqa: E501

        :return: The last_seen of this Device.  # noqa: E501
        :rtype: str
        """
        return self._last_seen

    @last_seen.setter
    def last_seen(self, last_seen):
        """Sets the last_seen of this Device.

        A datetime string with the format YYYY-MM-DDThh:mm:ss.SSSZ representing the last time the user interacted with this device.  # noqa: E501

        :param last_seen: The last_seen of this Device.  # noqa: E501
        :type: str
        """

        self._last_seen = last_seen

    @property
    def push_notification_token(self):
        """Gets the push_notification_token of this Device.  # noqa: E501

        The token used for push notifications on Android and iOS devices.  # noqa: E501

        :return: The push_notification_token of this Device.  # noqa: E501
        :rtype: str
        """
        return self._push_notification_token

    @push_notification_token.setter
    def push_notification_token(self, push_notification_token):
        """Sets the push_notification_token of this Device.

        The token used for push notifications on Android and iOS devices.  # noqa: E501

        :param push_notification_token: The push_notification_token of this Device.  # noqa: E501
        :type: str
        """
        if type(push_notification_token) is Undefined:
            push_notification_token = None
            self.nulls.discard("push_notification_token")
        elif push_notification_token is None:
            self.nulls.add("push_notification_token")
        else:
            self.nulls.discard("push_notification_token")

        self._push_notification_token = push_notification_token

    @property
    def info(self):
        """Gets the info of this Device.  # noqa: E501

        A flat curated object with properties that vary for each SDK platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :return: The info of this Device.  # noqa: E501
        :rtype: object
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this Device.

        A flat curated object with properties that vary for each SDK platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :param info: The info of this Device.  # noqa: E501
        :type: object
        """
        if type(info) is Undefined:
            info = None
            self.nulls.discard("info")
        elif info is None:
            self.nulls.add("info")
        else:
            self.nulls.discard("info")

        self._info = info

    @property
    def app_version(self):
        """Gets the app_version of this Device.  # noqa: E501

        Version of the mobile app in which the SDK is embedded. Not applicable for devices of type web.  # noqa: E501

        :return: The app_version of this Device.  # noqa: E501
        :rtype: str
        """
        return self._app_version

    @app_version.setter
    def app_version(self, app_version):
        """Sets the app_version of this Device.

        Version of the mobile app in which the SDK is embedded. Not applicable for devices of type web.  # noqa: E501

        :param app_version: The app_version of this Device.  # noqa: E501
        :type: str
        """
        if type(app_version) is Undefined:
            app_version = None
            self.nulls.discard("app_version")
        elif app_version is None:
            self.nulls.add("app_version")
        else:
            self.nulls.discard("app_version")

        self._app_version = app_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Device):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Device):
            return True

        return self.to_dict() != other.to_dict()
